Documentation
¶
Overview ¶
Options package holds the option settings for a single graph generation.
Index ¶
Constants ¶
const ( AppenderAll string = "_all_" GroupByVersion string = "version" NamespaceAll string = "all" NamespaceIstioSystem string = "istio-system" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
Appenders []appender.Appender
Duration time.Duration
IncludeIstio bool // include istio-system services. Ignored for istio-system ns. Default false.
Namespaces []string
QueryTime int64 // unix time in seconds
Workload string
Vendor string
VendorOptions
}
Options are all supported graph generation options.
func NewOptions ¶
type VendorOptions ¶
VendorOptions are those that are supplied to the vendor-specific generators.
Click to show internal directories.
Click to hide internal directories.